@@ -372,7 +372,7 @@ def get_data_call_params(**selection):
             params['showHistory'] = value
         elif key in ('show_revisions', 'reporting_history'):
             params['showReportingDate'] = value
-        elif key in ('start_date', 'end_date', 'insert_null', 'at_time', 'available_since'):
+        elif key in ('start_date', 'end_date', 'insert_null', 'at_time', 'available_since', 'coverage_threshold'):
             params[groclient.utils.str_snake_to_camel(key)] = value
     params['responseType'] = 'list_of_series'
     return params
@@ -566,7 +566,7 @@ def get_data_points(access_token, api_host, **selection):
             if len(missing_params) == 1
             else ', '.join(missing_params[:-1]) + ' and ' + missing_params[-1] + ' are'
         )
-        logger.error(message)
+        logger.warning(message)
         raise ValueError(message)
     resp = get_data(url, headers, params)
     include_historical = selection.get('include_historical', True)
